@@ -85,7 +85,7 @@
     </message>
     <message>
         <source>Ctrl+T</source>
-        <translation>Strg + T</translation>
+        <translation>Strg+T</translation>
     </message>
     <message>
         <source>Backgrounds</source>
@@ -101,7 +101,7 @@
     </message>
     <message>
         <source>Ctrl+Z</source>
-        <translation>Strg + Z</translation>
+        <translation>Strg+Z</translation>
     </message>
     <message>
         <source>Redo</source>
@@ -109,7 +109,7 @@
     </message>
     <message>
         <source>Ctrl+Y</source>
-        <translation>Strg + Y</translation>
+        <translation>Strg+Y</translation>
     </message>
     <message>
         <source>Previous</source>
@@ -141,7 +141,7 @@
     </message>
     <message>
         <source>Ctrl+D</source>
-        <translation>Strg + D</translation>
+        <translation>Strg+D</translation>
     </message>
     <message>
         <source>Web Browsing</source>
@@ -149,23 +149,23 @@
     </message>
     <message>
         <source>Ctrl+W</source>
-        <translation>Strg + W</translation>
+        <translation>Strg+W</translation>
     </message>
     <message>
         <source>Line</source>
-        <translation>Linie</translation>
+        <translation>Strichstärke</translation>
     </message>
     <message>
         <source>Small Line</source>
-        <translation>Kleine Linie</translation>
+        <translation>Dünner Strich</translation>
     </message>
     <message>
         <source>Medium Line</source>
-        <translation>Mittelgroße Linie</translation>
+        <translation>Mittelstarker Strich</translation>
     </message>
     <message>
         <source>Large Line</source>
-        <translation>Große Linie</translation>
+        <translation>Dicker Strich</translation>
     </message>
     <message>
         <source>Quit</source>
@@ -177,7 +177,7 @@
     </message>
     <message>
         <source>Smalle Eraser</source>
-        <translation>Kleiner Radiergummi</translation>
+        <translation type="vanished">Kleiner Radiergummi</translation>
     </message>
     <message>
         <source>Medium Eraser</source>
@@ -189,7 +189,7 @@
     </message>
     <message>
         <source>Color</source>
-        <translation>Farbe</translation>
+        <translation type="vanished">Farbe</translation>
     </message>
     <message>
         <source>Back</source>
@@ -245,7 +245,7 @@
     </message>
     <message>
         <source>Ctrl+B</source>
-        <translation>Strg + B</translation>
+        <translation>Strg+B</translation>
     </message>
     <message>
         <source>Erase</source>
@@ -273,7 +273,7 @@
     </message>
     <message>
         <source>Ctrl+L</source>
-        <translation>Strg + L</translation>
+        <translation>Strg+L</translation>
     </message>
     <message>
         <source>Show Desktop</source>
@@ -285,7 +285,7 @@
     </message>
     <message>
         <source>Ctrl+Shift+H</source>
-        <translation>Strg + Umschalt + H</translation>
+        <translation>Strg+Umschalt+H</translation>
     </message>
     <message>
         <source>Bigger</source>
@@ -353,7 +353,7 @@
     </message>
     <message>
         <source>Ctrl+O</source>
-        <translation>Strg + O</translation>
+        <translation>Strg+O</translation>
     </message>
     <message>
         <source>Duplicate</source>
@@ -545,7 +545,7 @@
     </message>
     <message>
         <source>Ctrl+I</source>
-        <translation>Strg + I</translation>
+        <translation>Strg+I</translation>
     </message>
     <message>
         <source>Erase Annotation</source>
@@ -553,7 +553,7 @@
     </message>
     <message>
         <source>Ctrl+E</source>
-        <translation>Strg + E</translation>
+        <translation>Strg+E</translation>
     </message>
     <message>
         <source>Marker</source>
@@ -565,7 +565,7 @@
     </message>
     <message>
         <source>Ctrl+M</source>
-        <translation>Strg + M</translation>
+        <translation>Strg+M</translation>
     </message>
     <message>
         <source>Selector</source>
@@ -577,7 +577,7 @@
     </message>
     <message>
         <source>Ctrl+F</source>
-        <translation>Strg + F</translation>
+        <translation>Strg+F</translation>
     </message>
     <message>
         <source>Hand</source>
@@ -597,7 +597,7 @@
     </message>
     <message>
         <source>Ctrl+G</source>
-        <translation>Strg + G</translation>
+        <translation>Strg+G</translation>
     </message>
     <message>
         <source>Draw Lines</source>
@@ -605,7 +605,7 @@
     </message>
     <message>
         <source>Ctrl+J</source>
-        <translation>Strg + J</translation>
+        <translation>Strg+J</translation>
     </message>
     <message>
         <source>Text</source>
@@ -617,7 +617,7 @@
     </message>
     <message>
         <source>Ctrl+K</source>
-        <translation>Strg + K</translation>
+        <translation>Strg+K</translation>
     </message>
     <message>
         <source>Capture</source>
@@ -757,7 +757,7 @@
     </message>
     <message>
         <source>Ctrl+H</source>
-        <translation>Strg + H</translation>
+        <translation>Strg+H</translation>
     </message>
     <message>
         <source>OpenBoard</source>
@@ -801,16 +801,44 @@
     </message>
     <message>
         <source>Ruled Light Background</source>
-        <translation>Hell linierter Hintergrund</translation>
+        <translation>Heller linierter Hintergrund</translation>
     </message>
     <message>
         <source>Ruled Dark Background</source>
-        <translation>Dunkel linierter Hintergrund</translation>
+        <translation>Dunkler linierter Hintergrund</translation>
     </message>
     <message>
         <source>Reset grid size</source>
         <translation>Rastergröße zurücksetzen</translation>
     </message>
+    <message>
+        <source>Small Eraser</source>
+        <translation>Kleiner Radiergummi</translation>
+    </message>
+    <message>
+        <source>Color 1</source>
+        <translation>Farbe 1</translation>
+    </message>
+    <message>
+        <source>Color 2</source>
+        <translation>Farbe 2</translation>
+    </message>
+    <message>
+        <source>Color 3</source>
+        <translation>Farbe 3</translation>
+    </message>
+    <message>
+        <source>Color 4</source>
+        <translation>Farbe 4</translation>
+    </message>
+    <message>
+        <source>Color 5</source>
+        <translation>Farbe 5</translation>
+    </message>
+    <message>
+        <source>Draw intermediate grid lines</source>
+        <translation>Gitter-Zwischenlinien zeichnen</translation>
+    </message>
 </context>
 <context>
     <name>PasswordDialog</name>
@@ -884,7 +912,7 @@
     <name>UBApplicationController</name>
     <message>
         <source>Web</source>
-        <translation>Internet</translation>
+        <translation>Browser</translation>
     </message>
     <message>
         <source>New update available, would you go to the web page ?</source>
@@ -913,6 +941,10 @@
         <source>Grid size</source>
         <translation>Gittergrösse</translation>
     </message>
+    <message>
+        <source>Draw intermediate grid lines</source>
+        <translation>Gitter-Zwischenlinien zeichnen</translation>
+    </message>
 </context>
 <context>
     <name>UBBoardController</name>
@@ -972,6 +1004,10 @@
         <source>Deleting page %1</source>
         <translation>Seite %1 löschen</translation>
     </message>
+    <message>
+        <source>Color</source>
+        <translation>Farbe</translation>
+    </message>
 </context>
 <context>
     <name>UBBoardPaletteManager</name>
@@ -1202,6 +1238,10 @@
         <source>Title page</source>
         <translation>Titelseite</translation>
     </message>
+    <message>
+        <source>Empty My Documents</source>
+        <translation type="vanished">Eigene Dokumente leeren</translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentManager</name>
@@ -1318,6 +1358,10 @@ Wenn Sie einen neuen Namen wählen, wird ein neues Dokument erstellt.</translati
         <source>Are you sure you want to remove the selected item(s) ?</source>
         <translation>Möchten Sie die ausgewählten Elemente wirklich entfernen ?</translation>
     </message>
+    <message>
+        <source>Copying page %1/%2</source>
+        <translation>Seite %1/%2 wird kopiert</translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentTreeWidget</name>
@@ -1633,7 +1677,7 @@ Wenn Sie einen neuen Namen wählen, wird ein neues Dokument erstellt.</translati
     </message>
     <message>
         <source>Animations</source>
-        <translation>Animationen</translation>
+        <translation type="vanished">Animationen</translation>
     </message>
     <message>
         <source>Interactivities</source>
@@ -2172,7 +2216,7 @@ Miniaturansicht der Seite %1 wird geladen</translation>
     </message>
     <message>
         <source>Compass</source>
-        <translation>Kompass</translation>
+        <translation>Zirkel</translation>
     </message>
     <message>
         <source>Protractor</source>
@@ -2190,6 +2234,10 @@ Miniaturansicht der Seite %1 wird geladen</translation>
         <source>Cache</source>
         <translation>Zwischenspeicher</translation>
     </message>
+    <message>
+        <source>Axes</source>
+        <translation>Achsen</translation>
+    </message>
 </context>
 <context>
     <name>UBTrapFlashController</name>
@@ -2549,6 +2597,13 @@ Bitte starten Sie die Anwendung erneut, um auf die aktualisierten Dokumente zugr
         <translation>In neuem Tab öffnen</translation>
     </message>
 </context>
+<context>
+    <name>XPDFRenderer</name>
+    <message>
+        <source>Processing...</source>
+        <translation>Verarbeitung…</translation>
+    </message>
+</context>
 <context>
     <name>YouTubePublishingDialog</name>
     <message>
@@ -2616,7 +2671,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Line Width</source>
-        <translation>Linienstärke</translation>
+        <translation>Strichstärke</translation>
     </message>
     <message>
         <source>Medium</source>
@@ -2886,6 +2941,34 @@ p, li { white-space: pre-wrap; }
         <source>Credits</source>
         <translation></translation>
     </message>
+    <message>
+        <source>Documents Mode</source>
+        <translation>Dokumentmodus</translation>
+    </message>
+    <message>
+        <source>Display date column on alphabetical sort</source>
+        <translation>Datumsspalte nur in alphabetischer Reihenfolge anzeigen</translation>
+    </message>
+    <message>
+        <source>Empty trash for documents older than</source>
+        <translation>Dokumente aus dem Papierkorb löschen, die älter als</translation>
+    </message>
+    <message>
+        <source>days</source>
+        <translation>Tage sind</translation>
+    </message>
+    <message>
+        <source>PDF Rendering</source>
+        <translation>PDF-Wiedergabe</translation>
+    </message>
+    <message>
+        <source>Enable quality loss to increase zoom performances</source>
+        <translation type="vanished">Zulassen eines Qualitätsverlusts zur Erhöhung der Zoomleistung</translation>
+    </message>
+    <message>
+        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
+        <translation>Die Zoomgeschwindigkeit verbessern (kann die Renderqualität geringfügig beeinträchtigen)</translation>
+    </message>
 </context>
 <context>
     <name>trapFlashDialog</name>
