@@ -183,10 +183,6 @@
         <source>Eraser</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Smalle Eraser</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Medium Eraser</source>
         <translation type="unfinished"></translation>
@@ -195,10 +191,6 @@
         <source>Large Eraser</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Color</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Back</source>
         <translation type="unfinished"></translation>
@@ -811,6 +803,34 @@
         <source>Reset grid size</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Small Eraser</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 5</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Draw intermediate grid lines</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PasswordDialog</name>
@@ -909,6 +929,10 @@
         <source>Grid size</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Draw intermediate grid lines</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBBoardController</name>
@@ -964,6 +988,10 @@
         <source>All Supported (%1)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Color</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBBoardPaletteManager</name>
@@ -1126,10 +1154,6 @@
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Empty</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Page %1</source>
         <translation type="unfinished"></translation>
@@ -1138,6 +1162,10 @@
         <source>Title page</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Empty</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentManager</name>
@@ -1486,10 +1514,6 @@ Providing a new name will create a new document.</source>
         <source>Pictures</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Animations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Interactivities</source>
         <translation type="unfinished"></translation>
@@ -1988,6 +2012,10 @@ Do you want to ignore these errors for this host?</source>
         <source>Cache</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Axes</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBTrapFlashController</name>
@@ -2346,6 +2374,13 @@ Please reboot the application to access the updated documents.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>XPDFRenderer</name>
+    <message>
+        <source>Processing...</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>YouTubePublishingDialog</name>
     <message>
@@ -2668,6 +2703,14 @@ p, li { white-space: pre-wrap; }
         <source>days</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>PDF Rendering</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>trapFlashDialog</name>
