@@ -261,7 +261,7 @@
     </message>
     <message>
         <source>Smalle Eraser</source>
-        <translation>Gomme fine</translation>
+        <translation type="vanished">Gomme fine</translation>
     </message>
     <message>
         <source>Medium Eraser</source>
@@ -273,7 +273,7 @@
     </message>
     <message>
         <source>Color</source>
-        <translation>Couleur</translation>
+        <translation type="vanished">Couleur</translation>
     </message>
     <message>
         <source>Back</source>
@@ -812,6 +812,34 @@
         <source>Reset grid size</source>
         <translation>Réinitialiser la taille du quadrillage</translation>
     </message>
+    <message>
+        <source>Small Eraser</source>
+        <translation>Gomme fine</translation>
+    </message>
+    <message>
+        <source>Color 1</source>
+        <translation>Couleur 1</translation>
+    </message>
+    <message>
+        <source>Color 2</source>
+        <translation>Couleur 2</translation>
+    </message>
+    <message>
+        <source>Color 3</source>
+        <translation>Couleur 3</translation>
+    </message>
+    <message>
+        <source>Color 4</source>
+        <translation>Couleur 4</translation>
+    </message>
+    <message>
+        <source>Color 5</source>
+        <translation>Couleur 5</translation>
+    </message>
+    <message>
+        <source>Draw intermediate grid lines</source>
+        <translation>Dessiner des lignes intermédiaires</translation>
+    </message>
 </context>
 <context>
     <name>PasswordDialog</name>
@@ -918,6 +946,10 @@
         <source>Grid size</source>
         <translation>Taille du quadrillage</translation>
     </message>
+    <message>
+        <source>Draw intermediate grid lines</source>
+        <translation>Dessiner des lignes intermédiaires</translation>
+    </message>
 </context>
 <context>
     <name>UBBoardController</name>
@@ -977,6 +1009,10 @@
         <source>Deleting page %1</source>
         <translation>Supression de la page %1</translation>
     </message>
+    <message>
+        <source>Color</source>
+        <translation>Couleur</translation>
+    </message>
 </context>
 <context>
     <name>UBBoardPaletteManager</name>
@@ -1211,6 +1247,10 @@
         <source>Title page</source>
         <translation>page Titre</translation>
     </message>
+    <message>
+        <source>Empty My Documents</source>
+        <translation type="vanished">Vider Mes Documents</translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentManager</name>
@@ -1650,7 +1690,7 @@ Un nouveau nom vous permettra de conserver l&apos;ancien document.</translation>
     </message>
     <message>
         <source>Animations</source>
-        <translation>Animations</translation>
+        <translation type="vanished">Animations</translation>
     </message>
     <message>
         <source>Interactivities</source>
@@ -2206,6 +2246,10 @@ Voulez-vous ignorer les erreurs pour ce serveur ?</translation>
         <source>Cache</source>
         <translation>Spot</translation>
     </message>
+    <message>
+        <source>Axes</source>
+        <translation>Axes</translation>
+    </message>
 </context>
 <context>
     <name>UBTrapFlashController</name>
@@ -2566,6 +2610,13 @@ Veuillez redémarrer l&apos;application pour accéder aux documents mis à jour.
         <translation>Ouvrir dans un nouvel onglet</translation>
     </message>
 </context>
+<context>
+    <name>XPDFRenderer</name>
+    <message>
+        <source>Processing...</source>
+        <translation>Traitement en cours...</translation>
+    </message>
+</context>
 <context>
     <name>YouTubePublishingDialog</name>
     <message>
@@ -2789,7 +2840,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Home Page:</source>
-        <translation>Page d&apos;accueil :</translation>
+        <translation>Page d&apos;accueil&#xa0;:</translation>
     </message>
     <message>
         <source>version : …</source>
@@ -2923,6 +2974,18 @@ p, li { white-space: pre-wrap; }
         <source>days</source>
         <translation>jours</translation>
     </message>
+    <message>
+        <source>PDF Rendering</source>
+        <translation>Rendu PDF</translation>
+    </message>
+    <message>
+        <source>Enable quality loss to increase zoom performances</source>
+        <translation type="vanished">Activer la perte de qualité pour améliorer les performaces de zoom</translation>
+    </message>
+    <message>
+        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
+        <translation>Améliorer la vitesse d&apos;exécution du zoom (peut légèrement affecter la qualité du rendu)</translation>
+    </message>
 </context>
 <context>
     <name>trapFlashDialog</name>
