@@ -425,7 +425,7 @@
     </message>
     <message>
         <source>Smalle Eraser</source>
-        <translation>Kis radír</translation>
+        <translation type="vanished">Kis radír</translation>
     </message>
     <message>
         <source>Medium Eraser</source>
@@ -437,7 +437,7 @@
     </message>
     <message>
         <source>Color</source>
-        <translation>Szín</translation>
+        <translation type="vanished">Szín</translation>
     </message>
     <message>
         <source>Reload Current Page</source>
@@ -811,6 +811,34 @@
         <source>Reset grid size</source>
         <translation>Rácsméret alaphelyzetbe állítása</translation>
     </message>
+    <message>
+        <source>Small Eraser</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 5</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Draw intermediate grid lines</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PasswordDialog</name>
@@ -913,6 +941,10 @@
         <source>Grid size</source>
         <translation>Rács mérete</translation>
     </message>
+    <message>
+        <source>Draw intermediate grid lines</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBBoardController</name>
@@ -968,6 +1000,10 @@
         <source>Deleting page %1</source>
         <translation>%1. oldal törlése</translation>
     </message>
+    <message>
+        <source>Color</source>
+        <translation type="unfinished">Szín</translation>
+    </message>
 </context>
 <context>
     <name>UBBoardPaletteManager</name>
@@ -1567,7 +1603,7 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Animations</source>
-        <translation>Animációk</translation>
+        <translation type="vanished">Animációk</translation>
     </message>
     <message>
         <source>Interactivities</source>
@@ -2115,6 +2151,10 @@ Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
         <source>Cache</source>
         <translation>Gyorsítótár</translation>
     </message>
+    <message>
+        <source>Axes</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBTrapFlashController</name>
@@ -2473,6 +2513,13 @@ Please reboot the application to access the updated documents.</source>
         <translation>Megnyitás új fülön</translation>
     </message>
 </context>
+<context>
+    <name>XPDFRenderer</name>
+    <message>
+        <source>Processing...</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>YouTubePublishingDialog</name>
     <message>
@@ -2799,6 +2846,14 @@ p, li { white-space: pre-wrap; }
         <source>days</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>PDF Rendering</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>trapFlashDialog</name>
