@@ -371,6 +371,7 @@ void UBApplicationController::showBoard()
 
     mIsShowingDesktop = false;
     UBPlatformUtils::setDesktopMode(false);
+    UBDrawingController::drawingController()->setInDesktopMode(false);
 
     mUninoteController->hideWindow();
 
@@ -473,7 +474,7 @@ void UBApplicationController::showDesktop(bool dontSwitchFrontProcess)
         UBPlatformUtils::bringPreviousProcessToFront();
     }
 
-    UBDrawingController::drawingController()->setInDestopMode(true);
+    UBDrawingController::drawingController()->setInDesktopMode(true);
     UBDrawingController::drawingController()->setStylusTool(UBStylusTool::Selector);
 }
 
@@ -543,19 +544,17 @@ void UBApplicationController::downloadJsonFinished(QString currentJson)
           }
     */
 
-    QScriptValue scriptValue;
-    QScriptEngine scriptEngine;
-    scriptValue = scriptEngine.evaluate ("(" + currentJson + ")");
+    QJsonObject jsonObject = QJsonDocument::fromJson(currentJson.toUtf8()).object();
 
     UBVersion installedVersion (qApp->applicationVersion());
-    UBVersion jsonVersion (scriptValue.property("version").toString());
+    UBVersion jsonVersion (jsonObject.value("version").toString());
 
     qDebug() << "json version: " << jsonVersion.toUInt();
     qDebug() << "installed version: " << installedVersion.toUInt();
 
     if (jsonVersion > installedVersion) {
         if (UBApplication::mainWindow->yesNoQuestion(tr("Update available"), tr ("New update available, would you go to the web page ?"))){
-            QUrl url(scriptValue.property("url").toString());
+            QUrl url(jsonObject.value("url").toString());
             QDesktopServices::openUrl(url);
         }
     }
