@@ -191,6 +191,7 @@ class UBSettings : public QObject
         static int defaultCrossSize;
         static int minCrossSize;
         static int maxCrossSize;
+        static bool intermediateLines;
 
         static int colorPaletteSize;
         static int objectFrameWidth;
@@ -360,6 +361,9 @@ class UBSettings : public QObject
         UBSetting* pdfPageFormat;
         UBSetting* pdfResolution;
 
+        UBSetting* pdfZoomBehavior;
+        UBSetting* enableQualityLossToIncreaseZoomPerfs;
+
         UBSetting* podcastFramesPerSecond;
         UBSetting* podcastVideoSize;
         UBSetting* podcastWindowsMediaBitsPerSecond;
@@ -422,6 +426,9 @@ class UBSettings : public QObject
         UBSetting* magnifierDrawingMode;
         UBSetting* autoSaveInterval;
 
+        UBSetting* enableToolAxes;
+        UBSetting* enableIntermediateLines;
+
     public slots:
 
         void setPenWidthIndex(int index);
