@@ -84,8 +84,9 @@ UBDesktopAnnotationController::UBDesktopAnnotationController(QObject *parent, UB
     mTransparentDrawingView->setAttribute(Qt::WA_TranslucentBackground, true);
 #ifdef Q_OS_OSX
     mTransparentDrawingView->setAttribute(Qt::WA_MacNoShadow, true);
-#endif
-    mTransparentDrawingView->setWindowFlags(Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::Window | Qt::NoDropShadowWindowHint);
+#endif //Q_OS_OSX
+
+    mTransparentDrawingView->setWindowFlags(Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::Window | Qt::NoDropShadowWindowHint | Qt::X11BypassWindowManagerHint);
     mTransparentDrawingView->setCacheMode(QGraphicsView::CacheNone);
     mTransparentDrawingView->resize(UBApplication::desktop()->width(), UBApplication::desktop()->height());
 
@@ -111,7 +112,7 @@ UBDesktopAnnotationController::UBDesktopAnnotationController(QObject *parent, UB
         connect( UBApplication::boardController->paletteManager()->mKeyboardPalette, SIGNAL(keyboardActivated(bool)), 
                  mTransparentDrawingView, SLOT(virtualKeyboardActivated(bool)));
 
-#ifdef Q_OS_LINUX
+#ifdef UB_REQUIRES_MASK_UPDATE
         connect(UBApplication::boardController->paletteManager()->mKeyboardPalette, SIGNAL(moved(QPoint)), this, SLOT(refreshMask()));
         connect(UBApplication::mainWindow->actionVirtualKeyboard, SIGNAL(triggered(bool)), this, SLOT(refreshMask()));
         connect(mDesktopPalette,SIGNAL(refreshMask()), this, SLOT(refreshMask()));
@@ -166,7 +167,7 @@ UBDesktopAnnotationController::UBDesktopAnnotationController(QObject *parent, UB
     connect(&mHoldTimerMarker, SIGNAL(timeout()), this, SLOT(markerActionReleased()));
     connect(&mHoldTimerEraser, SIGNAL(timeout()), this, SLOT(eraserActionReleased()));
 
-#ifdef Q_OS_LINUX
+#ifdef UB_REQUIRES_MASK_UPDATE
     connect(mDesktopPalette, SIGNAL(moving()), this, SLOT(refreshMask()));
     connect(UBApplication::boardController->paletteManager()->rightPalette(), SIGNAL(resized()), this, SLOT(refreshMask()));
     connect(UBApplication::boardController->paletteManager()->addItemPalette(), SIGNAL(closed()), this, SLOT(refreshMask()));
@@ -346,9 +347,9 @@ void UBDesktopAnnotationController::showWindow()
 
     mDesktopPalette->appear();
 
-#ifdef Q_OS_LINUX
+#ifdef UB_REQUIRES_MASK_UPDATE
     updateMask(true);
-#endif
+#endif // UB_REQUIRES_MASK_UPDATE
 }
 
 
@@ -364,12 +365,21 @@ void UBDesktopAnnotationController::close()
 void UBDesktopAnnotationController::stylusToolChanged(int tool)
 {
     Q_UNUSED(tool);
-//     UBStylusTool::Enum eTool = (UBStylusTool::Enum)tool;
-//     if(eTool != UBStylusTool::Selector && eTool != UBStylusTool::Text)
-//     {
-//         if(mKeyboardPalette->m_isVisible)
-//             UBApplication::mainWindow->actionVirtualKeyboard->activate(QAction::Trigger);
-//     }
+#ifdef Q_OS_OSX
+    /* no longer needed
+     if (UBDrawingController::drawingController()->isInDesktopMode())
+     {
+         UBStylusTool::Enum eTool = (UBStylusTool::Enum)tool;
+         if(eTool == UBStylusTool::Selector)
+         {
+             UBPlatformUtils::toggleFinder(true);
+         }
+         else
+         {
+             UBPlatformUtils::toggleFinder(false);
+         }
+     }*/
+#endif
 
     updateBackground();
 }
@@ -383,9 +393,9 @@ void UBDesktopAnnotationController::updateBackground()
             || UBDrawingController::drawingController()->stylusTool() == UBStylusTool::Selector)
     {
         newBrush = QBrush(Qt::transparent);
-#ifdef Q_OS_LINUX
+#ifdef UB_REQUIRES_MASK_UPDATE
         updateMask(true);
-#endif
+#endif //UB_REQUIRES_MASK_UPDATE
     }
     else
     {
@@ -394,9 +404,9 @@ void UBDesktopAnnotationController::updateBackground()
 #else
         newBrush = QBrush(QColor(127, 127, 127, 1));
 #endif
-#ifdef Q_OS_LINUX
+#ifdef UB_REQUIRES_MASK_UPDATE
         updateMask(false);
-#endif
+#endif //UB_REQUIRES_MASK_UPDATE
     }
 
     if (mTransparentDrawingScene && mTransparentDrawingScene->backgroundBrush() != newBrush)
@@ -902,7 +912,6 @@ void UBDesktopAnnotationController::updateMask(bool bTransparent)
             p.drawRect(tabsPalette);
         }
 
-#ifdef Q_OS_LINUX
         //Rquiered only for compiz wm
         //TODO. Window manager detection screen
 
@@ -910,7 +919,6 @@ void UBDesktopAnnotationController::updateMask(bool bTransparent)
             p.drawRect(UBApplication::boardController->paletteManager()->addItemPalette()->geometry());
         }
 
-#endif
 
         p.end();
 
@@ -948,9 +956,20 @@ void UBDesktopAnnotationController::updateMask(bool bTransparent)
     }
     else
     {
-        // Remove the mask
-        QPixmap noMask(mTransparentDrawingView->width(), mTransparentDrawingView->height());
-        mTransparentDrawingView->setMask(noMask.mask());
+        mMask = QPixmap(mTransparentDrawingView->width(), mTransparentDrawingView->height());
+        mMask.fill(Qt::transparent);
+
+        QPainter p;
+
+        p.begin(&mMask);
+
+        p.setPen(Qt::red);
+        p.setBrush(QBrush(Qt::red));
+
+        p.drawRect(mTransparentDrawingView->geometry().x(), mTransparentDrawingView->geometry().y(), mTransparentDrawingView->width(), mTransparentDrawingView->height());
+        p.end();
+
+        mTransparentDrawingView->setMask(mMask.mask());
     }
 }
 
